# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlMDataStd module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlmdatastd.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlMDataStd
else:
    import _XmlMDataStd

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlMDataStd.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlMDataStd.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMDataStd.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMDataStd.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlMDataStd.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDataStd.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlMDataStd.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlMDataStd.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlMDataStd.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlMDataStd.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMDataStd.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDataStd.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDataStd.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMDataStd.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMDataStd.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMDataStd.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlMDataStd.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlMDataStd:
_XmlMDataStd.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlMDataStd.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.XmlMDF
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlMDataStd_AsciiStringDriver_Create() -> "opencascade::handle< XmlMDataStd_AsciiStringDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_AsciiStringDriver_Create()

def Handle_XmlMDataStd_AsciiStringDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_AsciiStringDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_AsciiStringDriver_DownCast(t)

def Handle_XmlMDataStd_AsciiStringDriver_IsNull(t: "opencascade::handle< XmlMDataStd_AsciiStringDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_AsciiStringDriver_IsNull(t)

def Handle_XmlMDataStd_BooleanArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_BooleanArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanArrayDriver_Create()

def Handle_XmlMDataStd_BooleanArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_BooleanArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanArrayDriver_DownCast(t)

def Handle_XmlMDataStd_BooleanArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_BooleanArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanArrayDriver_IsNull(t)

def Handle_XmlMDataStd_BooleanListDriver_Create() -> "opencascade::handle< XmlMDataStd_BooleanListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanListDriver_Create()

def Handle_XmlMDataStd_BooleanListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_BooleanListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanListDriver_DownCast(t)

def Handle_XmlMDataStd_BooleanListDriver_IsNull(t: "opencascade::handle< XmlMDataStd_BooleanListDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanListDriver_IsNull(t)

def Handle_XmlMDataStd_ByteArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_ByteArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ByteArrayDriver_Create()

def Handle_XmlMDataStd_ByteArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ByteArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ByteArrayDriver_DownCast(t)

def Handle_XmlMDataStd_ByteArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ByteArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ByteArrayDriver_IsNull(t)

def Handle_XmlMDataStd_ExpressionDriver_Create() -> "opencascade::handle< XmlMDataStd_ExpressionDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExpressionDriver_Create()

def Handle_XmlMDataStd_ExpressionDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ExpressionDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExpressionDriver_DownCast(t)

def Handle_XmlMDataStd_ExpressionDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ExpressionDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ExpressionDriver_IsNull(t)

def Handle_XmlMDataStd_ExtStringArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_ExtStringArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringArrayDriver_Create()

def Handle_XmlMDataStd_ExtStringArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ExtStringArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringArrayDriver_DownCast(t)

def Handle_XmlMDataStd_ExtStringArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ExtStringArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringArrayDriver_IsNull(t)

def Handle_XmlMDataStd_ExtStringListDriver_Create() -> "opencascade::handle< XmlMDataStd_ExtStringListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringListDriver_Create()

def Handle_XmlMDataStd_ExtStringListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ExtStringListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringListDriver_DownCast(t)

def Handle_XmlMDataStd_ExtStringListDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ExtStringListDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringListDriver_IsNull(t)

def Handle_XmlMDataStd_GenericEmptyDriver_Create() -> "opencascade::handle< XmlMDataStd_GenericEmptyDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericEmptyDriver_Create()

def Handle_XmlMDataStd_GenericEmptyDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_GenericEmptyDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericEmptyDriver_DownCast(t)

def Handle_XmlMDataStd_GenericEmptyDriver_IsNull(t: "opencascade::handle< XmlMDataStd_GenericEmptyDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericEmptyDriver_IsNull(t)

def Handle_XmlMDataStd_GenericExtStringDriver_Create() -> "opencascade::handle< XmlMDataStd_GenericExtStringDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericExtStringDriver_Create()

def Handle_XmlMDataStd_GenericExtStringDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_GenericExtStringDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericExtStringDriver_DownCast(t)

def Handle_XmlMDataStd_GenericExtStringDriver_IsNull(t: "opencascade::handle< XmlMDataStd_GenericExtStringDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericExtStringDriver_IsNull(t)

def Handle_XmlMDataStd_IntPackedMapDriver_Create() -> "opencascade::handle< XmlMDataStd_IntPackedMapDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntPackedMapDriver_Create()

def Handle_XmlMDataStd_IntPackedMapDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_IntPackedMapDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntPackedMapDriver_DownCast(t)

def Handle_XmlMDataStd_IntPackedMapDriver_IsNull(t: "opencascade::handle< XmlMDataStd_IntPackedMapDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_IntPackedMapDriver_IsNull(t)

def Handle_XmlMDataStd_IntegerArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_IntegerArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerArrayDriver_Create()

def Handle_XmlMDataStd_IntegerArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_IntegerArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerArrayDriver_DownCast(t)

def Handle_XmlMDataStd_IntegerArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_IntegerArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerArrayDriver_IsNull(t)

def Handle_XmlMDataStd_IntegerDriver_Create() -> "opencascade::handle< XmlMDataStd_IntegerDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerDriver_Create()

def Handle_XmlMDataStd_IntegerDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_IntegerDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerDriver_DownCast(t)

def Handle_XmlMDataStd_IntegerDriver_IsNull(t: "opencascade::handle< XmlMDataStd_IntegerDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerDriver_IsNull(t)

def Handle_XmlMDataStd_IntegerListDriver_Create() -> "opencascade::handle< XmlMDataStd_IntegerListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerListDriver_Create()

def Handle_XmlMDataStd_IntegerListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_IntegerListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerListDriver_DownCast(t)

def Handle_XmlMDataStd_IntegerListDriver_IsNull(t: "opencascade::handle< XmlMDataStd_IntegerListDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerListDriver_IsNull(t)

def Handle_XmlMDataStd_NamedDataDriver_Create() -> "opencascade::handle< XmlMDataStd_NamedDataDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_NamedDataDriver_Create()

def Handle_XmlMDataStd_NamedDataDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_NamedDataDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_NamedDataDriver_DownCast(t)

def Handle_XmlMDataStd_NamedDataDriver_IsNull(t: "opencascade::handle< XmlMDataStd_NamedDataDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_NamedDataDriver_IsNull(t)

def Handle_XmlMDataStd_RealArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_RealArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealArrayDriver_Create()

def Handle_XmlMDataStd_RealArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_RealArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealArrayDriver_DownCast(t)

def Handle_XmlMDataStd_RealArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_RealArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_RealArrayDriver_IsNull(t)

def Handle_XmlMDataStd_RealDriver_Create() -> "opencascade::handle< XmlMDataStd_RealDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealDriver_Create()

def Handle_XmlMDataStd_RealDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_RealDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealDriver_DownCast(t)

def Handle_XmlMDataStd_RealDriver_IsNull(t: "opencascade::handle< XmlMDataStd_RealDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_RealDriver_IsNull(t)

def Handle_XmlMDataStd_RealListDriver_Create() -> "opencascade::handle< XmlMDataStd_RealListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealListDriver_Create()

def Handle_XmlMDataStd_RealListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_RealListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealListDriver_DownCast(t)

def Handle_XmlMDataStd_RealListDriver_IsNull(t: "opencascade::handle< XmlMDataStd_RealListDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_RealListDriver_IsNull(t)

def Handle_XmlMDataStd_ReferenceArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_ReferenceArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceArrayDriver_Create()

def Handle_XmlMDataStd_ReferenceArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ReferenceArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceArrayDriver_DownCast(t)

def Handle_XmlMDataStd_ReferenceArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ReferenceArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceArrayDriver_IsNull(t)

def Handle_XmlMDataStd_ReferenceListDriver_Create() -> "opencascade::handle< XmlMDataStd_ReferenceListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceListDriver_Create()

def Handle_XmlMDataStd_ReferenceListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ReferenceListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceListDriver_DownCast(t)

def Handle_XmlMDataStd_ReferenceListDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ReferenceListDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceListDriver_IsNull(t)

def Handle_XmlMDataStd_TreeNodeDriver_Create() -> "opencascade::handle< XmlMDataStd_TreeNodeDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_TreeNodeDriver_Create()

def Handle_XmlMDataStd_TreeNodeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_TreeNodeDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_TreeNodeDriver_DownCast(t)

def Handle_XmlMDataStd_TreeNodeDriver_IsNull(t: "opencascade::handle< XmlMDataStd_TreeNodeDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_TreeNodeDriver_IsNull(t)

def Handle_XmlMDataStd_UAttributeDriver_Create() -> "opencascade::handle< XmlMDataStd_UAttributeDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_UAttributeDriver_Create()

def Handle_XmlMDataStd_UAttributeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_UAttributeDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_UAttributeDriver_DownCast(t)

def Handle_XmlMDataStd_UAttributeDriver_IsNull(t: "opencascade::handle< XmlMDataStd_UAttributeDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_UAttributeDriver_IsNull(t)

def Handle_XmlMDataStd_VariableDriver_Create() -> "opencascade::handle< XmlMDataStd_VariableDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_VariableDriver_Create()

def Handle_XmlMDataStd_VariableDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_VariableDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_VariableDriver_DownCast(t)

def Handle_XmlMDataStd_VariableDriver_IsNull(t: "opencascade::handle< XmlMDataStd_VariableDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_VariableDriver_IsNull(t)
class xmlmdatastd(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute drivers to <adrivertable>.

        Parameters
        ----------
        aDriverTable: XmlMDF_ADriverTable
        anMsgDrv: Message_Messenger

        Returns
        -------
        None

        """
        return _XmlMDataStd.xmlmdatastd_AddDrivers(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlMDataStd.xmlmdatastd_swiginit(self, _XmlMDataStd.new_xmlmdatastd())
    __swig_destroy__ = _XmlMDataStd.delete_xmlmdatastd

# Register xmlmdatastd in _XmlMDataStd:
_XmlMDataStd.xmlmdatastd_swigregister(xmlmdatastd)

def xmlmdatastd_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute drivers to <adrivertable>.

    Parameters
    ----------
    aDriverTable: XmlMDF_ADriverTable
    anMsgDrv: Message_Messenger

    Returns
    -------
    None

    """
    return _XmlMDataStd.xmlmdatastd_AddDrivers(*args)

class XmlMDataStd_AsciiStringDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_AsciiStringDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_AsciiStringDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        Persistent -> transient (retrieve).

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        Transient -> persistent (store).

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_AsciiStringDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_AsciiStringDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_AsciiStringDriver

# Register XmlMDataStd_AsciiStringDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_AsciiStringDriver_swigregister(XmlMDataStd_AsciiStringDriver)

class XmlMDataStd_BooleanArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_BooleanArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_BooleanArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_BooleanArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_BooleanArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_BooleanArrayDriver

# Register XmlMDataStd_BooleanArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_BooleanArrayDriver_swigregister(XmlMDataStd_BooleanArrayDriver)

class XmlMDataStd_BooleanListDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_BooleanListDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_BooleanListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_BooleanListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_BooleanListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_BooleanListDriver

# Register XmlMDataStd_BooleanListDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_BooleanListDriver_swigregister(XmlMDataStd_BooleanListDriver)

class XmlMDataStd_ByteArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ByteArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ByteArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ByteArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ByteArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ByteArrayDriver

# Register XmlMDataStd_ByteArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ByteArrayDriver_swigregister(XmlMDataStd_ByteArrayDriver)

class XmlMDataStd_ExpressionDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ExpressionDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ExpressionDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ExpressionDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ExpressionDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ExpressionDriver

# Register XmlMDataStd_ExpressionDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ExpressionDriver_swigregister(XmlMDataStd_ExpressionDriver)

class XmlMDataStd_ExtStringArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ExtStringArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ExtStringArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ExtStringArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ExtStringArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ExtStringArrayDriver

# Register XmlMDataStd_ExtStringArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ExtStringArrayDriver_swigregister(XmlMDataStd_ExtStringArrayDriver)

class XmlMDataStd_ExtStringListDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ExtStringListDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ExtStringListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ExtStringListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ExtStringListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ExtStringListDriver

# Register XmlMDataStd_ExtStringListDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ExtStringListDriver_swigregister(XmlMDataStd_ExtStringListDriver)

class XmlMDataStd_GenericEmptyDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_GenericEmptyDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_GenericEmptyDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_GenericEmptyDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_GenericEmptyDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_GenericEmptyDriver

# Register XmlMDataStd_GenericEmptyDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_GenericEmptyDriver_swigregister(XmlMDataStd_GenericEmptyDriver)

class XmlMDataStd_GenericExtStringDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_GenericExtStringDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_GenericExtStringDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_GenericExtStringDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_GenericExtStringDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_GenericExtStringDriver

# Register XmlMDataStd_GenericExtStringDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_GenericExtStringDriver_swigregister(XmlMDataStd_GenericExtStringDriver)

class XmlMDataStd_IntPackedMapDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_IntPackedMapDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_IntPackedMapDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        Persistent -> transient (retrieve).

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        Transient -> persistent (store).

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_IntPackedMapDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_IntPackedMapDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_IntPackedMapDriver

# Register XmlMDataStd_IntPackedMapDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_IntPackedMapDriver_swigregister(XmlMDataStd_IntPackedMapDriver)

class XmlMDataStd_IntegerArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_IntegerArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_IntegerArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_IntegerArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_IntegerArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_IntegerArrayDriver

# Register XmlMDataStd_IntegerArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_IntegerArrayDriver_swigregister(XmlMDataStd_IntegerArrayDriver)

class XmlMDataStd_IntegerDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_IntegerDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_IntegerDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_IntegerDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_IntegerDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_IntegerDriver

# Register XmlMDataStd_IntegerDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_IntegerDriver_swigregister(XmlMDataStd_IntegerDriver)

class XmlMDataStd_IntegerListDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_IntegerListDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_IntegerListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_IntegerListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_IntegerListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_IntegerListDriver

# Register XmlMDataStd_IntegerListDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_IntegerListDriver_swigregister(XmlMDataStd_IntegerListDriver)

class XmlMDataStd_NamedDataDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_NamedDataDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_NamedDataDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_NamedDataDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_NamedDataDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_NamedDataDriver

# Register XmlMDataStd_NamedDataDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_NamedDataDriver_swigregister(XmlMDataStd_NamedDataDriver)

class XmlMDataStd_RealArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_RealArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_RealArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_RealArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_RealArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_RealArrayDriver

# Register XmlMDataStd_RealArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_RealArrayDriver_swigregister(XmlMDataStd_RealArrayDriver)

class XmlMDataStd_RealDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_RealDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_RealDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_RealDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_RealDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_RealDriver

# Register XmlMDataStd_RealDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_RealDriver_swigregister(XmlMDataStd_RealDriver)

class XmlMDataStd_RealListDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_RealListDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_RealListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_RealListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_RealListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_RealListDriver

# Register XmlMDataStd_RealListDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_RealListDriver_swigregister(XmlMDataStd_RealListDriver)

class XmlMDataStd_ReferenceArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ReferenceArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ReferenceArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ReferenceArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ReferenceArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ReferenceArrayDriver

# Register XmlMDataStd_ReferenceArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ReferenceArrayDriver_swigregister(XmlMDataStd_ReferenceArrayDriver)

class XmlMDataStd_ReferenceListDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ReferenceListDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ReferenceListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ReferenceListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ReferenceListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ReferenceListDriver

# Register XmlMDataStd_ReferenceListDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ReferenceListDriver_swigregister(XmlMDataStd_ReferenceListDriver)

class XmlMDataStd_TreeNodeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_TreeNodeDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_TreeNodeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_TreeNodeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_TreeNodeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_TreeNodeDriver

# Register XmlMDataStd_TreeNodeDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_TreeNodeDriver_swigregister(XmlMDataStd_TreeNodeDriver)

class XmlMDataStd_UAttributeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_UAttributeDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_UAttributeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_UAttributeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_UAttributeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_UAttributeDriver

# Register XmlMDataStd_UAttributeDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_UAttributeDriver_swigregister(XmlMDataStd_UAttributeDriver)

class XmlMDataStd_VariableDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_VariableDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_VariableDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_VariableDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_VariableDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_VariableDriver

# Register XmlMDataStd_VariableDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_VariableDriver_swigregister(XmlMDataStd_VariableDriver)








PYTHONOCC_VERSION_MAJOR = 7
PYTHONOCC_VERSION_MINOR = 5
PYTHONOCC_VERSION_PATCH = 0

#  Empty for official releases, set to -dev, -rc1, etc for development releases
PYTHONOCC_VERSION_DEVEL = '-dev'

VERSION = "%s.%s.%s%s" % (PYTHONOCC_VERSION_MAJOR, PYTHONOCC_VERSION_MINOR,
                          PYTHONOCC_VERSION_PATCH, PYTHONOCC_VERSION_DEVEL)



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
CSLib module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_cslib.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CSLib
else:
    import _CSLib

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _CSLib.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _CSLib.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _CSLib.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _CSLib.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _CSLib.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _CSLib.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _CSLib.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _CSLib.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _CSLib.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _CSLib.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _CSLib.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _CSLib.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _CSLib.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _CSLib.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _CSLib.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _CSLib.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _CSLib.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _CSLib:
_CSLib.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _CSLib.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TColgp
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *

CSLib_Singular = _CSLib.CSLib_Singular
CSLib_Defined = _CSLib.CSLib_Defined
CSLib_InfinityOfSolutions = _CSLib.CSLib_InfinityOfSolutions
CSLib_D1NuIsNull = _CSLib.CSLib_D1NuIsNull
CSLib_D1NvIsNull = _CSLib.CSLib_D1NvIsNull
CSLib_D1NIsNull = _CSLib.CSLib_D1NIsNull
CSLib_D1NuNvRatioIsNull = _CSLib.CSLib_D1NuNvRatioIsNull
CSLib_D1NvNuRatioIsNull = _CSLib.CSLib_D1NvNuRatioIsNull
CSLib_D1NuIsParallelD1Nv = _CSLib.CSLib_D1NuIsParallelD1Nv
CSLib_Done = _CSLib.CSLib_Done
CSLib_D1uIsNull = _CSLib.CSLib_D1uIsNull
CSLib_D1vIsNull = _CSLib.CSLib_D1vIsNull
CSLib_D1IsNull = _CSLib.CSLib_D1IsNull
CSLib_D1uD1vRatioIsNull = _CSLib.CSLib_D1uD1vRatioIsNull
CSLib_D1vD1uRatioIsNull = _CSLib.CSLib_D1vD1uRatioIsNull
CSLib_D1uIsParallelD1v = _CSLib.CSLib_D1uIsParallelD1v


class CSLib_NormalStatus(IntEnum):
	CSLib_Singular = 0
	CSLib_Defined = 1
	CSLib_InfinityOfSolutions = 2
	CSLib_D1NuIsNull = 3
	CSLib_D1NvIsNull = 4
	CSLib_D1NIsNull = 5
	CSLib_D1NuNvRatioIsNull = 6
	CSLib_D1NvNuRatioIsNull = 7
	CSLib_D1NuIsParallelD1Nv = 8
CSLib_Singular = CSLib_NormalStatus.CSLib_Singular
CSLib_Defined = CSLib_NormalStatus.CSLib_Defined
CSLib_InfinityOfSolutions = CSLib_NormalStatus.CSLib_InfinityOfSolutions
CSLib_D1NuIsNull = CSLib_NormalStatus.CSLib_D1NuIsNull
CSLib_D1NvIsNull = CSLib_NormalStatus.CSLib_D1NvIsNull
CSLib_D1NIsNull = CSLib_NormalStatus.CSLib_D1NIsNull
CSLib_D1NuNvRatioIsNull = CSLib_NormalStatus.CSLib_D1NuNvRatioIsNull
CSLib_D1NvNuRatioIsNull = CSLib_NormalStatus.CSLib_D1NvNuRatioIsNull
CSLib_D1NuIsParallelD1Nv = CSLib_NormalStatus.CSLib_D1NuIsParallelD1Nv

class CSLib_DerivativeStatus(IntEnum):
	CSLib_Done = 0
	CSLib_D1uIsNull = 1
	CSLib_D1vIsNull = 2
	CSLib_D1IsNull = 3
	CSLib_D1uD1vRatioIsNull = 4
	CSLib_D1vD1uRatioIsNull = 5
	CSLib_D1uIsParallelD1v = 6
CSLib_Done = CSLib_DerivativeStatus.CSLib_Done
CSLib_D1uIsNull = CSLib_DerivativeStatus.CSLib_D1uIsNull
CSLib_D1vIsNull = CSLib_DerivativeStatus.CSLib_D1vIsNull
CSLib_D1IsNull = CSLib_DerivativeStatus.CSLib_D1IsNull
CSLib_D1uD1vRatioIsNull = CSLib_DerivativeStatus.CSLib_D1uD1vRatioIsNull
CSLib_D1vD1uRatioIsNull = CSLib_DerivativeStatus.CSLib_D1vD1uRatioIsNull
CSLib_D1uIsParallelD1v = CSLib_DerivativeStatus.CSLib_D1uIsParallelD1v

class cslib(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def DNNUV(*args) -> "gp_Vec":
        r"""
        -- computes the derivative of order nu in the -- direction u and nv in the direction v of the not -- normalized normal vector at the point p(u,v) the array dersurf contain the derivative (i,j) of the surface for i=0,nu+1 ; j=0,nv+1.

        Parameters
        ----------
        Nu: int
        Nv: int
        DerSurf: TColgp_Array2OfVec

        Returns
        -------
        gp_Vec
        Computes the derivatives of order nu in the direction nu and nv in the direction nv of the not normalized vector n(u,v) = ds1/du * ds2/dv (cases where we use an osculating surface) dersurf1 are the derivatives of s1.

        Parameters
        ----------
        Nu: int
        Nv: int
        DerSurf1: TColgp_Array2OfVec
        DerSurf2: TColgp_Array2OfVec

        Returns
        -------
        gp_Vec

        """
        return _CSLib.cslib_DNNUV(*args)

    @staticmethod
    def DNNormal(*args) -> "gp_Vec":
        r"""
        -- computes the derivative of order nu in the -- direction u and nv in the direction v of the normalized normal vector at the point p(u,v) array dernuv contain the derivative (i+iduref,j+idvref) of d1u ^ d1v for i=0,nu ; j=0,nv iduref and idvref correspond to a derivative of d1u ^ d1v which can be used to compute the normalized normal vector. in the regular cases , iduref=idvref=0.

        Parameters
        ----------
        Nu: int
        Nv: int
        DerNUV: TColgp_Array2OfVec
        Iduref: int,optional
        	default value is 0
        Idvref: int,optional
        	default value is 0

        Returns
        -------
        gp_Vec

        """
        return _CSLib.cslib_DNNormal(*args)

    @staticmethod
    def Normal(*args) -> "Standard_Integer &, Standard_Integer &":
        r"""
        The following functions computes the normal to a surface inherits functionwithderivative from math //! computes the normal direction of a surface as the cross product between d1u and d1v. if d1u has null length or d1v has null length or d1u and d1v are parallel the normal is undefined. to check that d1u and d1v are colinear the sinus of the angle between d1u and d1v is computed and compared with sintol. the normal is computed if thestatus == done else the thestatus gives the reason why the computation has failed.

        Parameters
        ----------
        D1U: gp_Vec
        D1V: gp_Vec
        SinTol: float
        theStatus: CSLib_DerivativeStatus
        Normal: gp_Dir

        Returns
        -------
        None
        If there is a singularity on the surface the previous method cannot compute the local normal. this method computes an approched normal direction of a surface. it does a limited development and needs the second derivatives on the surface as input data. it computes the normal as follow : n(u, v) = d1u ^ d1v n(u0+du,v0+dv) = n0 + dn/du(u0,v0) * du + dn/dv(u0,v0) * dv + eps with eps->0 so we can have the equivalence n ~ dn/du + dn/dv. dnu = ||dn/du|| and dnv = ||dn/dv|| //! . if dnu isnull (dnu <= resolution from gp) the answer done = true the normal direction is given by dn/dv . if dnv isnull (dnv <= resolution from gp) the answer done = true the normal direction is given by dn/du . if the two directions dn/du and dn/dv are parallel done = true the normal direction is given either by dn/du or dn/dv. to check that the two directions are colinear the sinus of the angle between these directions is computed and compared with sintol. . if dnu/dnv or dnv/dnu is lower or equal than real epsilon done = false, the normal is undefined . if dnu isnull and dnv is null done = false, there is an indetermination and we should do a limited developpement at order 2 (it means that we cannot omit eps). . if dnu is not null and dnv is not null done = false, there are an infinity of normals at the considered point on the surface.

        Parameters
        ----------
        D1U: gp_Vec
        D1V: gp_Vec
        D2U: gp_Vec
        D2V: gp_Vec
        D2UV: gp_Vec
        SinTol: float
        theStatus: CSLib_NormalStatus
        Normal: gp_Dir

        Returns
        -------
        Done: bool
        Computes the normal direction of a surface as the cross product between d1u and d1v.

        Parameters
        ----------
        D1U: gp_Vec
        D1V: gp_Vec
        MagTol: float
        theStatus: CSLib_NormalStatus
        Normal: gp_Dir

        Returns
        -------
        None
        Find the first order k0 of deriviative of nuv where: foreach order < k0 all the derivatives of nuv are null all the derivatives of nuv corresponding to the order k0 are collinear and have the same sens. in this case, normal at u,v is unique.

        Parameters
        ----------
        MaxOrder: int
        DerNUV: TColgp_Array2OfVec
        MagTol: float
        U: float
        V: float
        Umin: float
        Umax: float
        Vmin: float
        Vmax: float
        theStatus: CSLib_NormalStatus
        Normal: gp_Dir

        Returns
        -------
        OrderU: int
        OrderV: int

        """
        return _CSLib.cslib_Normal(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _CSLib.cslib_swiginit(self, _CSLib.new_cslib())
    __swig_destroy__ = _CSLib.delete_cslib

# Register cslib in _CSLib:
_CSLib.cslib_swigregister(cslib)

def cslib_DNNUV(*args) -> "gp_Vec":
    r"""
    -- computes the derivative of order nu in the -- direction u and nv in the direction v of the not -- normalized normal vector at the point p(u,v) the array dersurf contain the derivative (i,j) of the surface for i=0,nu+1 ; j=0,nv+1.

    Parameters
    ----------
    Nu: int
    Nv: int
    DerSurf: TColgp_Array2OfVec

    Returns
    -------
    gp_Vec
    Computes the derivatives of order nu in the direction nu and nv in the direction nv of the not normalized vector n(u,v) = ds1/du * ds2/dv (cases where we use an osculating surface) dersurf1 are the derivatives of s1.

    Parameters
    ----------
    Nu: int
    Nv: int
    DerSurf1: TColgp_Array2OfVec
    DerSurf2: TColgp_Array2OfVec

    Returns
    -------
    gp_Vec

    """
    return _CSLib.cslib_DNNUV(*args)

def cslib_DNNormal(*args) -> "gp_Vec":
    r"""
    -- computes the derivative of order nu in the -- direction u and nv in the direction v of the normalized normal vector at the point p(u,v) array dernuv contain the derivative (i+iduref,j+idvref) of d1u ^ d1v for i=0,nu ; j=0,nv iduref and idvref correspond to a derivative of d1u ^ d1v which can be used to compute the normalized normal vector. in the regular cases , iduref=idvref=0.

    Parameters
    ----------
    Nu: int
    Nv: int
    DerNUV: TColgp_Array2OfVec
    Iduref: int,optional
    	default value is 0
    Idvref: int,optional
    	default value is 0

    Returns
    -------
    gp_Vec

    """
    return _CSLib.cslib_DNNormal(*args)

def cslib_Normal(*args) -> "Standard_Integer &, Standard_Integer &":
    r"""
    The following functions computes the normal to a surface inherits functionwithderivative from math //! computes the normal direction of a surface as the cross product between d1u and d1v. if d1u has null length or d1v has null length or d1u and d1v are parallel the normal is undefined. to check that d1u and d1v are colinear the sinus of the angle between d1u and d1v is computed and compared with sintol. the normal is computed if thestatus == done else the thestatus gives the reason why the computation has failed.

    Parameters
    ----------
    D1U: gp_Vec
    D1V: gp_Vec
    SinTol: float
    theStatus: CSLib_DerivativeStatus
    Normal: gp_Dir

    Returns
    -------
    None
    If there is a singularity on the surface the previous method cannot compute the local normal. this method computes an approched normal direction of a surface. it does a limited development and needs the second derivatives on the surface as input data. it computes the normal as follow : n(u, v) = d1u ^ d1v n(u0+du,v0+dv) = n0 + dn/du(u0,v0) * du + dn/dv(u0,v0) * dv + eps with eps->0 so we can have the equivalence n ~ dn/du + dn/dv. dnu = ||dn/du|| and dnv = ||dn/dv|| //! . if dnu isnull (dnu <= resolution from gp) the answer done = true the normal direction is given by dn/dv . if dnv isnull (dnv <= resolution from gp) the answer done = true the normal direction is given by dn/du . if the two directions dn/du and dn/dv are parallel done = true the normal direction is given either by dn/du or dn/dv. to check that the two directions are colinear the sinus of the angle between these directions is computed and compared with sintol. . if dnu/dnv or dnv/dnu is lower or equal than real epsilon done = false, the normal is undefined . if dnu isnull and dnv is null done = false, there is an indetermination and we should do a limited developpement at order 2 (it means that we cannot omit eps). . if dnu is not null and dnv is not null done = false, there are an infinity of normals at the considered point on the surface.

    Parameters
    ----------
    D1U: gp_Vec
    D1V: gp_Vec
    D2U: gp_Vec
    D2V: gp_Vec
    D2UV: gp_Vec
    SinTol: float
    theStatus: CSLib_NormalStatus
    Normal: gp_Dir

    Returns
    -------
    Done: bool
    Computes the normal direction of a surface as the cross product between d1u and d1v.

    Parameters
    ----------
    D1U: gp_Vec
    D1V: gp_Vec
    MagTol: float
    theStatus: CSLib_NormalStatus
    Normal: gp_Dir

    Returns
    -------
    None
    Find the first order k0 of deriviative of nuv where: foreach order < k0 all the derivatives of nuv are null all the derivatives of nuv corresponding to the order k0 are collinear and have the same sens. in this case, normal at u,v is unique.

    Parameters
    ----------
    MaxOrder: int
    DerNUV: TColgp_Array2OfVec
    MagTol: float
    U: float
    V: float
    Umin: float
    Umax: float
    Vmin: float
    Vmax: float
    theStatus: CSLib_NormalStatus
    Normal: gp_Dir

    Returns
    -------
    OrderU: int
    OrderV: int

    """
    return _CSLib.cslib_Normal(*args)

class CSLib_Class2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs the 2d-polygon. thepnts2d is the set of the vertices (closed polygon will always be created inside of this constructor; consequently, there is no point in repeating first and last point in thepnts2d). thetolu and thetolv are tolerances. theumin, thevmin, theumax, thevmax are uv-bounds of the polygon.

        Parameters
        ----------
        thePnts2d: TColgp_Array1OfPnt2d
        theTolU: float
        theTolV: float
        theUMin: float
        theVMin: float
        theUMax: float
        theVMax: float

        Returns
        -------
        None
        Constructs the 2d-polygon. thepnts2d is the set of the vertices (closed polygon will always be created inside of this constructor; consequently, there is no point in repeating first and last point in thepnts2d). thetolu and thetolv are tolerances. theumin, thevmin, theumax, thevmax are uv-bounds of the polygon.

        Parameters
        ----------
        thePnts2d: TColgp_SequenceOfPnt2d
        theTolU: float
        theTolV: float
        theUMin: float
        theVMin: float
        theUMax: float
        theVMax: float

        Returns
        -------
        None

        """
        _CSLib.CSLib_Class2d_swiginit(self, _CSLib.new_CSLib_Class2d(*args))

    def InternalSiDans(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        X: float
        Y: float

        Returns
        -------
        int

        """
        return _CSLib.CSLib_Class2d_InternalSiDans(self, *args)

    def InternalSiDansOuOn(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        X: float
        Y: float

        Returns
        -------
        int

        """
        return _CSLib.CSLib_Class2d_InternalSiDansOuOn(self, *args)

    def SiDans(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt2d

        Returns
        -------
        int

        """
        return _CSLib.CSLib_Class2d_SiDans(self, *args)

    def SiDans_OnMode(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt2d
        Tol: float

        Returns
        -------
        int

        """
        return _CSLib.CSLib_Class2d_SiDans_OnMode(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _CSLib.delete_CSLib_Class2d

# Register CSLib_Class2d in _CSLib:
_CSLib.CSLib_Class2d_swigregister(CSLib_Class2d)

class CSLib_NormalPolyDef(OCC.Core.math.math_FunctionWithDerivative):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        k0: int
        li: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        _CSLib.CSLib_NormalPolyDef_swiginit(self, _CSLib.new_CSLib_NormalPolyDef(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _CSLib.delete_CSLib_NormalPolyDef

# Register CSLib_NormalPolyDef in _CSLib:
_CSLib.CSLib_NormalPolyDef_swigregister(CSLib_NormalPolyDef)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Expr import *
from OCC.Core.TCollection import *


class ExprIntrp_SequenceOfNamedExpression:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class ExprIntrp_SequenceOfNamedFunction:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class ExprIntrp_StackOfGeneralExpression:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class ExprIntrp_StackOfGeneralFunction:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class ExprIntrp_StackOfGeneralRelation:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class exprintrp:
	pass

class ExprIntrp_Analysis:
	def __init__(self) -> None: ...
	def GetFunction(self, name: TCollection_AsciiString) -> Expr_NamedFunction: ...
	def GetNamed(self, name: TCollection_AsciiString) -> Expr_NamedExpression: ...
	def IsExpStackEmpty(self) -> bool: ...
	def IsRelStackEmpty(self) -> bool: ...
	def Pop(self) -> Expr_GeneralExpression: ...
	def PopFunction(self) -> Expr_GeneralFunction: ...
	def PopName(self) -> TCollection_AsciiString: ...
	def PopRelation(self) -> Expr_GeneralRelation: ...
	def PopValue(self) -> int: ...
	def Push(self, exp: Expr_GeneralExpression) -> None: ...
	def PushFunction(self, func: Expr_GeneralFunction) -> None: ...
	def PushName(self, name: TCollection_AsciiString) -> None: ...
	def PushRelation(self, rel: Expr_GeneralRelation) -> None: ...
	def PushValue(self, degree: int) -> None: ...
	def ResetAll(self) -> None: ...
	def SetMaster(self, agen: ExprIntrp_Generator) -> None: ...
	@overload
	def Use(self, func: Expr_NamedFunction) -> None: ...
	@overload
	def Use(self, named: Expr_NamedExpression) -> None: ...

class ExprIntrp_Generator(Standard_Transient):
	def GetFunction(self, name: TCollection_AsciiString) -> Expr_NamedFunction: ...
	def GetFunctions(self) -> ExprIntrp_SequenceOfNamedFunction: ...
	@overload
	def GetNamed(self) -> ExprIntrp_SequenceOfNamedExpression: ...
	@overload
	def GetNamed(self, name: TCollection_AsciiString) -> Expr_NamedExpression: ...
	@overload
	def Use(self, func: Expr_NamedFunction) -> None: ...
	@overload
	def Use(self, named: Expr_NamedExpression) -> None: ...

class ExprIntrp_GenExp(ExprIntrp_Generator):
	@staticmethod
	def Create() -> ExprIntrp_GenExp: ...
	def Expression(self) -> Expr_GeneralExpression: ...
	def IsDone(self) -> bool: ...
	def Process(self, str: TCollection_AsciiString) -> None: ...

class ExprIntrp_GenFct(ExprIntrp_Generator):
	@staticmethod
	def Create() -> ExprIntrp_GenFct: ...
	def IsDone(self) -> bool: ...
	def Process(self, str: TCollection_AsciiString) -> None: ...

class ExprIntrp_GenRel(ExprIntrp_Generator):
	@staticmethod
	def Create() -> ExprIntrp_GenRel: ...
	def IsDone(self) -> bool: ...
	def Process(self, str: TCollection_AsciiString) -> None: ...
	def Relation(self) -> Expr_GeneralRelation: ...

# harray1 classes
# harray2 classes
# hsequence classes

ExprIntrp_GenExp_Create = ExprIntrp_GenExp.Create
ExprIntrp_GenFct_Create = ExprIntrp_GenFct.Create
ExprIntrp_GenRel_Create = ExprIntrp_GenRel.Create
